package com.rshy.project.hy.server;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.collection.CollectionUtil;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.http.HttpUtil;
import com.alibaba.fastjson.JSON;
import com.rshy.project.hy.config.properties.*;
import com.rshy.project.hy.model.constant.ItfwConstant;
import com.rshy.project.hy.model.constant.WebConstant;
import com.rshy.project.hy.server.dto.*;
import com.rshy.project.hy.server.param.AgentApiParam;
import com.rshy.project.hy.server.vo.*;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.data.redis.core.StringRedisTemplate;
import org.springframework.stereotype.Component;

import java.util.Set;
import java.util.concurrent.TimeUnit;


/**
 * @author: lileilei
 * @date: 2022/4/23 21:32
 * @description: 公安网代理服务
 */
@Component
@Slf4j
public class ItfwServer {
    @Value("${base.url}")
    private String baseUrl;
    @Autowired
    private PctjkmProperties pctjkmProperties;
    @Autowired
    private PctzdryProperties pctzdryProperties;
    @Autowired
    private PctztProperties pctztProperties;
    @Autowired
    private PctzfbaProperties pctzfbaProperties;
    @Autowired
    private PctdfkProperties pctdfkProperties;
    @Autowired
    private PctjsryProperties pctjsryProperties;
    @Autowired
    private PctxdryProperties pctxdryProperties;
    @Autowired
    private PctqkryProperties pctqkryProperties;
    @Autowired
    private PctrchlProperties pctrchlProperties;
    @Autowired
    private StringRedisTemplate stringRedisTemplate;

    /**
     * 基础服务访问
     *
     * @param param
     * @param timeout 超时时间 秒
     * @return
     */
    public String baseAgentApi(AgentApiParam param, Integer timeout) {
        return HttpUtil.post(baseUrl, JSON.toJSONString(param), timeout);
    }

    /**
     * 健康码服务
     *
     * @param barCode 健康码
     * @param timeout 超时时间 秒
     * @return
     */
    public PctjkmInfoDTO getPctjkm(String barCode, Integer timeout) {
        if (StringUtils.isBlank(barCode)) {
            log.warn("barCode为空");
            return null;
        }

        String cacheKey = new StringBuilder().append(ItfwConstant.BARCODE_KEY).append(barCode).toString();
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("健康码服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctjkmInfoDTO.class);
        }

        PctjkmProperties properties = new PctjkmProperties();
        BeanUtil.copyProperties(pctjkmProperties, properties);
        properties.setQuery(new BarcodeQueryDTO().setBar_code(barCode));
        log.info("健康码请求第三方接口入参信息：{}", JSON.toJSONString(properties));
        String body = this.baseAgentApi(properties, timeout);
        log.info("请求健康码服务响应信息：{}", body);
        if (StrUtil.isEmpty(body)) {
            return null;
        }

        PctjkmVO pctjkmVO = JSON.parseObject(body, PctjkmVO.class);
        if (CollectionUtil.isEmpty(pctjkmVO.getData().getResult())) {
            return null;
        }

        PctjkmInfoDTO pctjkmInfoDTO = pctjkmVO.getData().getResult().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctjkmInfoDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctjkmInfoDTO;
    }

    /**
     * 重点人员服务
     *
     * @param idNumber 身份证号
     * @param timeout  超时时间 秒
     * @return
     */
    public PctzdryDTO getPctzdry(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTZDRY_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("重点人员服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctzdryDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTZDRY_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctzdryProperties properties = new PctzdryProperties();
        BeanUtil.copyProperties(pctzdryProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber));
        log.info("重点人员服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;
        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求重点人员服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }
        log.info("重点人员服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctzdryVO pctzdryVO = JSON.parseObject(body, PctzdryVO.class);
        if (CollectionUtil.isEmpty(pctzdryVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctzdryDTO pctzdryDTO = pctzdryVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctzdryDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctzdryDTO;
    }

    /**
     * 人员劣迹服务
     *
     * @param idNumber
     * @param timeout  超时时间 秒
     * @return
     */
    public PctztDTO getPctzt(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTZT_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("人员劣迹服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctztDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTZT_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctztProperties properties = new PctztProperties();
        BeanUtil.copyProperties(pctztProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber));
        log.info("人员劣迹服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求人员劣迹服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        log.info("人员劣迹服务响应信息：{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        PctztVO pctztVO = JSON.parseObject(body, PctztVO.class);
        if (CollectionUtil.isEmpty(pctztVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctztDTO pctztDTO = pctztVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctztDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctztDTO;
    }

    /**
     * 新的执法办案服务
     *
     * @param idNumber
     * @param timeout  超时时间 妙
     * @return
     */
    public PctzfbaDTO getPctzfba(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTZFBA_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("执法办案服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctzfbaDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTZFBA_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctzfbaProperties properties = new PctzfbaProperties();
        BeanUtil.copyProperties(pctzfbaProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber).setBar_zjhm(StrUtil.EMPTY).setAjbh("ajbh"));
        log.info("新的执法办案服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求执法办案服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }

        log.info("新的执法办案服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctzfbaVO pctzfbaVO = JSON.parseObject(body, PctzfbaVO.class);

        if (CollectionUtil.isEmpty(pctzfbaVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctzfbaDTO pctzfbaDTO = pctzfbaVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctzfbaDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctzfbaVO.getData().stream().findFirst().get();
    }

    /**
     * 打防控信息服务
     *
     * @param idNumber 身份证号
     * @param ajbh
     * @param timeout  超时时间 秒
     * @return
     */
    public PctdfkDTO getPctdfk(String idNumber, String ajbh, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTDFK_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("打防控信息服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctdfkDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTDFK_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctdfkProperties properties = new PctdfkProperties();
        BeanUtil.copyProperties(pctdfkProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber).setAjbh(ajbh));
        log.info("打防控信息服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;
        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求打防控信息服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }
        log.info("打防控信息服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctdfkVO pctdfkVO = JSON.parseObject(body, PctdfkVO.class);
        if (CollectionUtil.isEmpty(pctdfkVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctdfkDTO pctdfkDTO = pctdfkVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctdfkDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctdfkDTO;
    }

    /**
     * 监所人员服务
     *
     * @param idNumber
     * @param timeout
     * @return
     */
    public PctjsryDTO getPctjsry(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTJSRY_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("监所人员服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctjsryDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTJSRY_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctjsryProperties properties = new PctjsryProperties();
        BeanUtil.copyProperties(pctjsryProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber));
        log.info("监所人员服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求监所人员服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }

        log.info("监所人员服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctjsryVO pctjsryVO = JSON.parseObject(body, PctjsryVO.class);
        if (CollectionUtil.isEmpty(pctjsryVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctjsryDTO pctjsryDTO = pctjsryVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctjsryDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctjsryDTO;
    }

    /**
     * 吸毒人员服务
     *
     * @param idNumber
     * @param xm
     * @param timeout
     * @return
     */
    public PctxdryDTO getPctxdry(String idNumber, String xm, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTXDRY_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("吸毒人员服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctxdryDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTXDRY_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctxdryProperties properties = new PctxdryProperties();
        BeanUtil.copyProperties(pctxdryProperties, properties);
        properties.setQuery(new QueryDTO().setZjid(StrUtil.EMPTY).setXm(StrUtil.EMPTY).setZjhm(idNumber).setZjzldm(StrUtil.EMPTY)
                .setZjzl(StrUtil.EMPTY).setChrq(StrUtil.EMPTY));
        log.info("吸毒人员服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求吸毒人员服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }

        log.info("吸毒人员服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctxdryVO pctxdryVO = JSON.parseObject(body, PctxdryVO.class);
        if (CollectionUtil.isEmpty(pctxdryVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctxdryDTO pctxdryDTO = pctxdryVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctxdryDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctxdryDTO;
    }


    /**
     * 前科人员服务
     *
     * @param idNumber
     * @param timeout
     * @return
     */
    public PctqkryDTO getPctqkry(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTQKRY_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("前科人员服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctqkryDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTQKRY_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctqkryProperties properties = new PctqkryProperties();
        BeanUtil.copyProperties(pctqkryProperties, properties);
        properties.setQuery(new QueryDTO().setZjhm(idNumber));
        log.info("前科人员服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }
            log.error("请求前科人员服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }

        log.info("前科人员服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);
        if (StrUtil.isEmpty(body)) {
            return null;
        }
        PctqkryVO pctqkryVO = JSON.parseObject(body, PctqkryVO.class);
        if (CollectionUtil.isEmpty(pctqkryVO.getData())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctqkryDTO pctqkryDTO = pctqkryVO.getData().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctqkryDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctqkryDTO;
    }

    /**
     * 异常次数
     *
     * @param key
     * @return
     */
    private Integer times(String key) {
        String cacheKey = key + ":times";
        int times = 1;
        String timesStr = stringRedisTemplate.opsForValue().get(cacheKey);
        if (timesStr == null) {
            stringRedisTemplate.opsForValue().set(cacheKey, String.valueOf(times));//,DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        } else {
            times = Integer.parseInt(timesStr) + 1;
            if (times > WebConstant.TIMEOUT_TIMES) {
                Set<String> keys = stringRedisTemplate.keys(cacheKey + "*");
                stringRedisTemplate.delete(keys);
            } else {
                stringRedisTemplate.opsForValue().increment(cacheKey);
            }
        }

        return times;
    }

    /**
     * 人车核录
     *
     * @param idNumber
     * @param timeout
     */
    public PctrchlDTO getPctrchl(String idNumber, Integer timeout) {
        if (StringUtils.isBlank(idNumber)) {
            return null;
        }

        String cacheKey = idNumber + ':' + ItfwConstant.PCTRCHL_KEY;
        String cacheValue = stringRedisTemplate.opsForValue().get(cacheKey);
        if (StrUtil.isNotEmpty(cacheValue)) {
            log.info("人车核录服务走缓存读取，响应内容： {}", cacheValue);
            return JSON.parseObject(cacheValue, PctrchlDTO.class);
        }

        String cacheStatusKey = ItfwConstant.PCTRCHL_STATUS_KEY;
        String cacheStatusValue = stringRedisTemplate.opsForValue().get(cacheStatusKey);
        if (StrUtil.isNotEmpty(cacheStatusValue)) {
            return null;
        }

        PctrchlProperties properties = new PctrchlProperties();
        BeanUtil.copyProperties(pctrchlProperties, properties);
        PctrchlBodyDTO pctrchlBodyDTO = new PctrchlBodyDTO();
        pctrchlBodyDTO.setDlxx(new PctrchlDlxxDTO());
        pctrchlBodyDTO.setRyxx(new PctrchlRyxxDTO().setZjhm(idNumber));
        properties.setBody(pctrchlBodyDTO);
        log.info("人车核录服务请求入参:{}", JSON.toJSONString(properties));
        String body = null;

        try {
            body = this.baseAgentApi(properties, timeout);
        } catch (Exception e) {
            if (times(cacheStatusKey) > WebConstant.TIMEOUT_TIMES) {
                stringRedisTemplate.opsForValue().set(cacheStatusKey, cacheStatusKey, WebConstant.STATUS_TIMEOUT, TimeUnit.MINUTES);
            }

            log.error("请求人车核录服务接口超时异常：{} {}", e.getMessage(), e.getLocalizedMessage());
            e.printStackTrace();
            return null;
        }

        log.info("人车核录服务响应信息:{}", body);
        Set<String> keys = stringRedisTemplate.keys(cacheStatusKey + "*");
        stringRedisTemplate.delete(keys);

        if (StrUtil.isEmpty(body) || !StrUtil.containsAnyIgnoreCase(body, "datas")) {
            return null;
        }
        PctrchlVO pctrchlVO = JSON.parseObject(body, PctrchlVO.class);
        if (CollectionUtil.isEmpty(pctrchlVO.getDatas())) {
            stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(null), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
            return null;
        }

        PctrchlDTO pctrchlDTO = pctrchlVO.getDatas().stream().findFirst().get();
        stringRedisTemplate.opsForValue().set(cacheKey, JSON.toJSONString(pctrchlDTO), DateUtil.endOfDay(DateUtil.date()).getTime() - DateUtil.date().getTime(), TimeUnit.MILLISECONDS);
        return pctrchlDTO;
    }

}
